Let's even put raw numbers to it. DifferentialEquations.jl usage has seen compile times drop from 22 seconds to 3 seconds over the last few months.
https://github.com/SciML/DifferentialEquations.jl/issues/786
https://github.com/SciML/DifferentialEquations.jl/issues/786
There may well have also been improvements in the Julia compiler.